def checker(redis_pwd: str) -> str:
    return f"""#!/var/lib/ecp-veil/node/env/bin/python3.9

from redis import ConnectionPool, Redis
from veilrpc.utils.bazalt import REDIS_MASTER_STATUS

FILE_PATH = '/var/log/veil/consul_controller.log'


def write_status(msg: str):
    with open(FILE_PATH, 'w') as l_file:
        l_file.write(msg)


def main():
    try:
        REDIS_POOL = ConnectionPool.from_url('redis://:{redis_pwd}@localhost:6379/0')
        REDIS_CLIENT = Redis(connection_pool=REDIS_POOL)
        value = REDIS_CLIENT.get('REDIS_MASTER_STATUS').decode()
        if value == '0':
            write_status("Status controller: DOWN\\n")
            exit(2)
        write_status("Status controller: UP\\n")
        exit(0)
    except Exception as err:
        write_status(f"Status redis: DOWN\\n" + str(err) + "\\n")
        exit(1)


main()
"""


def controller_service() -> str:
    service_controller = {
        "service": {
            "name": "controller-service",
            "tags": ["cnt-ping"],
            "check": {
                "id": "controller-ping",
                "name": "Controller redis ping",
                "args": ["/etc/consul.d/scripts/controller.py"],
                "interval": "1s",
                "timeout": "1s"
            }
        }
    }
    return service_controller
